@@ -6,7 +6,7 @@ use Template;
 use Template::Timer;
 use NEXT;
 
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
 __PACKAGE__->mk_accessors('template');
 
@@ -105,7 +105,8 @@ stored in C<< $c->response->output >>.
 
 sub process {
     my ( $self, $c ) = @_;
-    $c->res->headers->content_type('text/html;charset=utf8');
+    $c->res->headers->content_type('text/html; charset=utf-8') 
+    unless $c->res->headers->content_type();
     my $output;
     my $name = $c->stash->{template} || $c->req->match;
     unless ($name) {
